@@ -4,7 +4,7 @@
 # @Email  : 877362867@qq.com
 # @Date   : 2020/05/30 22:43
 
-
+import builtins
 import enum
 import html
 import inspect
@@ -155,8 +155,8 @@ class Browser(Explorer):
                 app = 'chrome'
             elif msedge_dir in paths:
                 app = 'msedge'
-            else:
-                app = 'explorer'
+            else:  # 默认使用谷歌。之前试过explorer不行~~
+                app = 'C:/Program Files/Google/Chrome/Application/chrome.exe'
         super().__init__(app, shell)
 
     @classmethod
@@ -468,6 +468,11 @@ def showdir(c, *, to_html=None, printf=True, width=200):
     return res
 
 
+# 注册进builtins，可以在任意地方直接使用
+setattr(builtins, 'browser', browser)
+setattr(builtins, 'showdir', showdir)
+
+
 def render_echart(ob, name, show=False):
     """ 渲染显示echart图表
 
